/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * © 2016 OX Software GmbH
 *
 * @author Daniel Rentz <daniel.rentz@open-xchange.com>
 */

define('io.ox/office/text/main', [
    'io.ox/office/text/app/application'
], function (TextApplication) {

    'use strict';

    // entry point for the OX AppSuite front-end to launch a new OX Text instance
    return TextApplication.createLauncher();

});
